%% FDI filter performance analysis
% This file reads simulation data corresponding to faulty and healthy
% flights and implements the FDI filter. The report generated by the file
% is displayed after the simulation is complete.

%% Clean up
% clear all
close all, bdclose all, clc

%% Set variables of the nonlinear and linear responses
% load ([pwd, '\Simulation results\May 21, 2014\simres_L_Uf_cz.mat']);
% load ([pwd, '\Simulation results\May 21, 2014\simres_NL_Fbp_cz.mat']);
% load ([pwd, '\Simulation results\May 21, 2014\simres_NL_Ftp_cz.mat']);
SIL_mod = SIL;
Lin_mod = Lin;
r2d = 180/pi;

%% Detection variables
detvar = {'beta', 'p', 'r'};
% detvar = {'beta', 'phi', 'psi'};
% Comparing {'beta', 'phi', 'psi'} results in fewer missed detections, but
% more false alarms.
detcomp = [1, 1, -1]; % the vector to be compared to

%% Check that the files loaded are correct
SIL_mod.siminfo
Lin_mod.siminfo

if ~strcmp(SIL_mod.siminfo(1:7), 'SIL_sim')
    error('The model loaded into SIL_mod is not from the SIL_sim.');
end
if ~strcmp(Lin_mod.siminfo(1:7), 'Lin_sim')
    error('The model loaded into Lin_mod is not from the Lin_sim.');
end

%% Generate thresholds for each error signal
load sigma % MAT file containing the sigma values for the different measurements.

% Setting thresholds
thresh.beta = 3*sigma.beta*r2d;
thresh.phi = 1*sigma.p*r2d;
thresh.psi = 1*sigma.r*r2d;
thresh.p = 4*sigma.p*r2d;
thresh.r = 7*sigma.r*r2d;
thresh.rud = 4;
thresh.rail = 0.3;

%% Generate error signals (struct e) by subtracting Lin from SIL
e.time = SIL_mod.time;
e.beta = (SIL_mod.beta*r2d) - (Lin_mod.beta_L + Lin_mod.TrimCondition.WindAxesIni(3)*r2d);
e.phi = (SIL_mod.phi*r2d) - (Lin_mod.phi_L + Lin_mod.TrimCondition.AttitudeIni(1)*r2d);
e.psi = (SIL_mod.psi*r2d) - (Lin_mod.psi_L + Lin_mod.TrimCondition.AttitudeIni(3)*r2d);
e.p = (SIL_mod.p*r2d) - (Lin_mod.p_L);
e.r = (SIL_mod.r*r2d) - (Lin_mod.r_L);
e.rud = (SIL_mod.rudder*r2d) - (Lin_mod.rudder_L + Lin_mod.TrimCondition.Inputs.CtrlSurf(2)*r2d);
e.rail = (SIL_mod.r_aileron*r2d) - (Lin_mod.r_aileron_L + Lin_mod.TrimCondition.Inputs.CtrlSurf(4)*r2d);

%% Detection stage
% Call the FDI_detect function
detect = FDI_detect(thresh, e, detvar, detcomp);

% Display the hitting time results of the detection stage
detect.hittime.frame
detect.hittime.sustain
detect.hittime.global

%% Isolation stage
% Call the FDI_isolate_estimate function
IE = FDI_isolate_estimate(thresh, e, detect);

%% Report generation
if isfield(IE, 'terminate')
    report = IE.terminate; % error protection
else
    report = [SIL_mod.siminfo, '\nDetection time: ', num2str(detect.hittime.global), ' seconds.'...
                '\nIsolation and estimation time: ', num2str(IE.hittime), ' seconds.'...
                '\nFault estimate: ', IE.source, ' rudder stuck at ', ...
                num2str(-1*IE.est.rud), ' degrees.\n']; % report
end
fprintf(report);

%% Plotting results
% FDI_plot % plot all residuals, flags, global flag
% FDI_plot2 % plot the results in \subsection{Results\Wind gusts}
FDI_plot3 % plot the results in \subsection{Results\Maneuvers}
