%% NL_sim_vs_Lin_sim
% This file is used to validate the linearization that is carried out on
% the nonlinear model. The time responses of the linear model (from
% UAV_Lin.mdl) and the nonlinear model (from UAV_SIL.mdl) are compared
% here.

%% Clean up
close all
bdclose all
clc

%% Set variables of the nonlinear and linear responses
SIL_mod = SIL;
Lin_mod = Lin;
r2d = 180/pi;

%% Check that the files loaded are correct
SIL_mod.siminfo
Lin_mod.siminfo

if ~strcmp(SIL_mod.siminfo(1:7), 'SIL_sim')
    error('The model loaded into SIL_mod is not from the SIL_sim.');
end
if ~strcmp(Lin_mod.siminfo(1:7), 'Lin_sim')
    error('The model loaded into Lin_mod is not from the Lin_sim.');
end

%% Plot responses of the outputs
figure; % V, alpha, and beta
subplot(311);
plot(SIL_mod.time, SIL_mod.V_s, Lin_mod.time_L, Lin_mod.V_L + Lin_mod.TrimCondition.WindAxesIni(1));
xlabel('Time, t [s]');
ylabel('Airspeed, V [m/s]');
legend('Nonlinear', 'Linear');
subplot(312);
plot(SIL_mod.time, SIL_mod.alpha*r2d, Lin_mod.time_L, Lin_mod.alpha_L + Lin_mod.TrimCondition.WindAxesIni(2)*r2d);
xlabel('Time, t [s]');
ylabel('Alpha, \alpha [deg]');
legend('Nonlinear', 'Linear');
subplot(313);
plot(SIL_mod.time, SIL_mod.beta*r2d, Lin_mod.time_L, Lin_mod.beta_L + Lin_mod.TrimCondition.WindAxesIni(3)*r2d);
xlabel('Time, t [s]');
ylabel('Beta, \beta [deg]');
legend('Nonlinear', 'Linear');

figure; % phi, theta, and psi
subplot(311);
plot(SIL_mod.time, SIL_mod.phi*r2d, Lin_mod.time_L, Lin_mod.phi_L + Lin_mod.TrimCondition.AttitudeIni(1)*r2d);
xlabel('Time, t [s]');
ylabel('Phi, \phi [deg]');
legend('Nonlinear', 'Linear');
subplot(312);
plot(SIL_mod.time, SIL_mod.theta*r2d, Lin_mod.time_L, Lin_mod.theta_L + Lin_mod.TrimCondition.AttitudeIni(2)*r2d);
xlabel('Time, t [s]');
ylabel('Theta, \theta [deg]');
legend('Nonlinear', 'Linear');
subplot(313);
plot(SIL_mod.time, SIL_mod.psi*r2d, Lin_mod.time_L, Lin_mod.psi_L + Lin_mod.TrimCondition.AttitudeIni(3)*r2d);
xlabel('Time, t [s]');
ylabel('Psi, \psi [deg]');
legend('Nonlinear', 'Linear');

figure; % p, q, and r
subplot(311);
plot(SIL_mod.time, SIL_mod.p*r2d, Lin_mod.time_L, Lin_mod.p_L);
xlabel('Time, t [s]');
ylabel('Roll rate, p [deg/s]');
legend('Nonlinear', 'Linear');
subplot(312);
plot(SIL_mod.time, SIL_mod.q*r2d, Lin_mod.time_L, Lin_mod.q_L);
xlabel('Time, t [s]');
ylabel('Pitch rate, q [deg/s]');
legend('Nonlinear', 'Linear');
subplot(313);
plot(SIL_mod.time, SIL_mod.r*r2d, Lin_mod.time_L, Lin_mod.r_L);
xlabel('Time, t [s]');
ylabel('Yaw rate, r [deg/s]');
legend('Nonlinear', 'Linear');

%% Plot responses of the control commands
figure; % throttle and elevator
subplot(211);
plot(SIL_mod.time, SIL_mod.throttle, Lin_mod.time_L, Lin_mod.throttle_L + Lin_mod.TrimCondition.Inputs.Throttle);
xlabel('Time, t [s]');
ylabel('Throttle, \tau [nd]');
legend('Nonlinear', 'Linear');
subplot(212);
plot(SIL_mod.time, SIL_mod.elevator*r2d, Lin_mod.time_L, Lin_mod.elevator_L + Lin_mod.TrimCondition.Inputs.CtrlSurf(1)*r2d);
xlabel('Time, t [s]');
ylabel('Elevator, elev [deg]');
legend('Nonlinear', 'Linear');

figure; % rudder and aileron
subplot(211);
plot(SIL_mod.time, SIL_mod.rudder*r2d, Lin_mod.time_L, Lin_mod.rudder_L + Lin_mod.TrimCondition.Inputs.CtrlSurf(2)*r2d);
xlabel('Time, t [s]');
ylabel('Rudder, rud [deg]');
legend('Nonlinear', 'Linear');
subplot(212);
plot(SIL_mod.time, SIL_mod.r_aileron*r2d, Lin_mod.time_L, Lin_mod.r_aileron_L + Lin_mod.TrimCondition.Inputs.CtrlSurf(4)*r2d);
xlabel('Time, t [s]');
ylabel('Aileron, r_{ail} [deg]');
legend('Nonlinear', 'Linear');
